---
Title: Python interface
Authors: Tamas, Jutta
Topics:
  - installation
  - interface through software
status: dump
---

### Python environment

KM3NeT develops open source Python software for accessing and working with data
taken by the detector, produced in simulations or in other analysis pipelines
e.g. event reconstructions, and a number of other types like metadata,
provenance history and environmental data. The software is following the
Semantic Versioning 2.0 (https://semver.org) conventions and releases are
automatically triggered on the GitLab CI by annotated Git tags. These releases
including alpha and beta releases are uploaded to the publicly accessible Python
Package Index, which is the main repository of software for the Python
programming language. The installation of these packages is as simple as
executing `pip install PACKAGE_NAME`. Additionally, the packages can also be
installed directly from the GitLab repositories for example in case of
experimental branches.

The general philosophy behind all Python packages is to build a bridge to
commonly use open source scientific tools, libraries and frameworks. While the
common base is built on NumPy (https://numpy.org), the de facto standard for
scientific, numerical computing in Python, other popular packages 
from the SciPy stack (https://www.scipy.org) are highly preferred. Examples are
Matplotlib (https://matplotlib.org) to create publication quality plots, Pandas
(https://pandas.pydata.org) which is used to work with tabular data, Astropy
(https://www.astropy.org) for astronomical calculations or numba
(http://numba.pydata.org) for high-performance low level optimisations.

The output format is preferably CSV and JSON to maximise interoperability. For
larger or more complex datasets, two additional formats are supported. HDF5
(https://www.hdfgroup.org) which is a widely used data format in science and
accessible in many popular computer languages is used to store data from every
tier, including uncalibrated low-level data and high-level reconstruction
summaries. Additionally and mainly for astronomical data, the FITS
(https://fits.gsfc.nasa.gov) dataformat is available due to its high popularity
among astronomers.


### Python interface to KM3NeT data
#### openkm3
* Small python package to directly use open data in python from local computer 
* Interfaces with data center API, allows to query datasets (km3resources)
* Provides functions to download & interpret data products

#### Current capability
* Loading hdf-File as pandas DataFrame, reading additional parameter infos & provenance
* Reading histogram data as plain table, pandas Dataframe or automatically build plot
