---
Title: How to use VO SCS data
Author: Jutta
Topics:
  - summary from open course 
  - https://edu.km3net.de/course/accessing-the-km3net-open-data/

status: dump
---

## Accessing data through the VO server

A short [online course](https://edu.km3net.de/course/accessing-the-km3net-open-data/) has been provided at our Education Portal.

Complying with the standards set by IVOA, the KM3NeT open data are accessible with services defined by the Table Access Protocol (TAP). The services operating under this protocol allow the execution of queries in order to retrieve the data from the database tables as well as to inspect various metadata. The TAP services support SQL commands. It is highly recommended the queries to be written in Astronomical Data Query Language (ADQL). A nice introduction of ADQL used in a TAP service is found here. Another way to retrieve the data is the Simple Cone Search (SCS). This defines queries for sky search in a cone with given position and radius.

The standard Table Access Protocol allows the existance of TAP clients. The most widely used are the Aladin client as well as the TOPCAT client. The TAP clients interoperate and communicate under the Simple Application Messaging Protocol (SAMP). There is also an option to access the data via python scripting. This is possible using the pyVO, a package affiliated with Astropy.

### Using VO clients
Information on how to download and install Aladin is found at https://aladin.u-strasbg.fr/java/nph-aladin.pl?frame=downloading.

An introduction on how to use ADQL is found [here](http://docs.g-vo.org/adql/html/)

  * Aladin: https://aladin.u-strasbg.fr/java/nph-aladin.pl?frame=downloading .
  * TOPCAT: http://www.star.bris.ac.uk/~mbt/topcat/#install .

### Using the VO python interface
You can find information on how to install Astropy at https://www.astropy.org/ and for the pyVO at https://pyvo.readthedocs.io/en/latest/

Accessing data with Python:
  * Astropy: https://www.astropy.org/ .
  * PyVO: https://pyvo.readthedocs.io/en/latest/ .
  * Matplotlib: https://matplotlib.org/3.1.1/users/installing.html .

#### Example use

```python
import pyvo as vo

service = vo.dal.TAPService("http://vo.km3net.de/__system__/tap/run/tap")

# resultset works like a numpy record array
resultset = service.search("SELECT * FROM ant20_01.main")
print(resultset.fieldnames)
print(resultset)

resultset = service.search("SELECT * FROM ant20_01.main WHERE ABS(decl)<10 AND ABS(ra)<20 AND nhit>90")
print(resultset)

resultset = service.search("SELECT * FROM ant20_01.main WHERE ABS(mjd-57474.8)<1.0")
print(resultset)
```

### Courses on the education portal
  * Analysis and visualization with Aladin: https://edu.km3net.de/lesson/aladin/ .
  * Analysis and visualization with TOPCAT: https://edu.km3net.de/lesson/topcat-2/ .
  * A simple analysis in python: https://edu.km3net.de/lesson/a-simple-analysis-in-python/ .
  * Use case 1 - Correlate neutrino data with Gamma Ray Bursts: https://edu.km3net.de/lesson/correlating-with/ .
  * Use case 2 - Correlate neutrino data from different experiments: https://edu.km3net.de/lesson/correlate-neutrino-data-from-different-experiments/ .


### How to use the webinar materials
The webinar held using the Indico, a web-based management system for meetings [3]. An event created on Indico with open access [4], that means no credentials were required in order to participate. The Indico supports the option for a video room accessible from the event page. For the webinar though, a google meeting room was used linked in the description of the event's page.

There is an option for an Indico event to contain time slots in order to distribute the available time covering the different meeting topics. In these time slots, material can be assigned. In the case of the webinar, a time slot created for each educational video, with the link of the lesson's page which contain the video in the Virtual Education Center [5], added in the materials. The available time for each time slot was calculated from the video duration added to the time given to the participants to hands-on practise with the lesson's task. With the experience from this test webinar, the reccomendation to the coordinator is to give the participants 10 minutes to practise with the tasks of the Aladin & TOPCAT lessons, and 15 minutes with the tasks of the python lessons.       

[3]: https://indico.cern.ch/
[4]: https://indico.cern.ch/event/959379/  
[5]: Deliverable 4.11  
 

